/*
*  CATS BOX http://domotique.web2diz.net/
* 
*  This work is licensed under a Creative Commons Attribution-ShareAlike 4.0 International License
*  http://creativecommons.org/licenses/by-sa/4.0/. 
*  
*  You are free to:
*  
*  Share — copy and redistribute the material in any medium or format
*  Adapt — remix, transform, and build upon the material
*  for any purpose, even commercially.
*  
*  Under the following terms:
*  
*  Attribution — You must give appropriate credit, provide a link to the license, and indicate if changes were made. You may do so in any reasonable manner, but not in any way that suggests the licensor endorses you or your use.
*  ShareAlike — If you remix, transform, or build upon the material, you must distribute your contributions under the same license as the original.
*  
*  This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*/

/*-----( Import needed libraries )-----*/
#include <Stepper.h>
#include <x10rf.h>

/*-----( Declare Constants, Pin Numbers )-----*/
#define POSITION_PIN 12        	// OH3144E Hall Effect Sensor
#define BOUTON_1_PIN 2		// Bouton for manual rotation +
#define BOUTON_2_PIN 3		// Bouton for manual rotation -
#define RF_PIN 4 		// Pin number for the 433mhz transmitter
#define reps 5 			// Number of times that a RF command must be repeated.
#define ledpin 0                // BLUE_LED 0 = no output 
#define DOMO_COUNTER 11 	// Counter ID in domoticz this one can be set to 0 

//--- MOTOR PROPRERTIES AND SETTINGS --
#define STEPS_PER_MOTOR_REVOLUTION 32   
#define STEPS_PER_OUTPUT_REVOLUTION 32 * 64  //2048  
Stepper stepper(STEPS_PER_MOTOR_REVOLUTION, 8, 10, 9 ,  11);

//--- RF PROPERTIES AND SETTINGS
x10rf myx10 = x10rf(RF_PIN,ledpin,reps);


/*-----( Declare Variables )-----*/
int completeTurn= -STEPS_PER_OUTPUT_REVOLUTION;
int Speed = 300; //  900 max  //300 best
int count = 0;   // number or rotation
int timeS = 1;   // nor realy time but used as time for button long/short
int i = 0;
int previousState; 
int manual = 0;

void setup()  {
 Serial.begin(9600);
 myx10.begin();
}
 
void loop()  
{
// Doing a initialisation phase 

Serial.println("Initialisation phase START");
  stepper.setSpeed(Speed*2);
  stepper.step(completeTurn/20);
  stepper.step(-completeTurn/10);
 while ( digitalRead(POSITION_PIN)!= LOW)  
	{
	stepper.step(-5);
	}  
Serial.println("Initialisation phase END");
Serial.println("Waiting 8 sec now to see if there is any manual action requested");
// Initialisation completed


stepper.setSpeed(Speed*2);

// During the x nexts second we check if there is any manual action requested
Serial.println("Waiting for Manual action ");

while (timeS<80){
//  Manual 

if (digitalRead(BOUTON_1_PIN)== HIGH || digitalRead(BOUTON_2_PIN)== HIGH ){
manual = 1;
Serial.println("bouton pushed. Manual = "+ manual);

	 // direction 1
	 if (digitalRead(BOUTON_1_PIN)== HIGH && digitalRead(BOUTON_2_PIN)== LOW){
	 Serial.println("bouton 1 pushed");
		stepper.step(-5);
		i++;
		if(i>10){ // long push direction 1
		Serial.println("bouton long pushed");
		 while ( digitalRead(BOUTON_1_PIN)== HIGH)  {  // whille pushing 
				stepper.step(-5);
			}
		}
		if(i<10){ // short push direction 1
		 Serial.println("bouton short pushed");
		 while ( digitalRead(POSITION_PIN)!= LOW && i < 10 && digitalRead(BOUTON_2_PIN)== LOW)  {   // while mark not reached or new short push 
				stepper.step(-5);
                 if (digitalRead(BOUTON_1_PIN)== HIGH) i++;
                
			} 			
		}
	 }
     // direction 2 will come here
	 	 // direction 2
	 if (digitalRead(BOUTON_1_PIN)== LOW && digitalRead(BOUTON_2_PIN) == HIGH){
	 Serial.println("bouton 2 pushed");
		stepper.step(5);
		i++;
		if(i>10){ // long push direction 2
		Serial.println("bouton 2 long pushed");
		 while ( digitalRead(BOUTON_2_PIN)== HIGH)  {  // whille pushing 
				stepper.step(5);
			}
		}
		if(i<10){ // short push direction 2
		 Serial.println("bouton 2 short pushed");
		 while ( digitalRead(POSITION_PIN)!= LOW && i < 10 && digitalRead(BOUTON_1_PIN)== LOW)  {   // while mark not reached or new short push 
		          stepper.step(5);
                if (digitalRead(BOUTON_2_PIN)== HIGH) i++;

			} 			
		}
	 }

	/*
	if (digitalRead(BOUTON_1_PIN)== HIGH && digitalRead(BOUTON_2_PIN)== HIGH){
		// you can add someting here when the 2 botton are pushed 
	 }*/	 
	if (digitalRead(BOUTON_1_PIN)== LOW && digitalRead(BOUTON_2_PIN)== LOW){
		i=0;
          Serial.println("i set to 0");
	}
}

//check time only if no bouton pressed 
if (manual==0) {
Serial.println("No yet manual action.");
	timeS++;
	delay(100) ; // 1 sec.
	}
}

// If we come here this meand that the where no manual action during the last x seconds
// Set to automatic : doing a complete turn 
// Automatic steps can be stopped anytime it button are puched
Serial.println("No manual Action, I will do my automated job...");

  // while hall sensor not reached and button not puched 
  while ( count < 1 && (digitalRead(BOUTON_1_PIN)== LOW || digitalRead(BOUTON_2_PIN)== LOW ))  
  {
  stepper.setSpeed(300);
  stepper.step(-2);
   if (digitalRead(POSITION_PIN)== LOW && previousState != digitalRead(POSITION_PIN)) {
        count++ ;
   }
   previousState=digitalRead(POSITION_PIN);
}

// when the turn is completed, RFXmeter value is send to domoticz
// just to be able to check the motor is doing his job

myx10.RFXmeter(DOMO_COUNTER,5,count); 

Serial.println("Done, Now I will wait for a while befor taking a new turm...Zzzzz");

timeS=0;  

// Now I have finished my job, I will wait a while 
// Maenwhile the main switch will ne set to OFF
// if button are puchech I will come back to the begining of the loop.
while(  timeS < 3600 && digitalRead(BOUTON_1_PIN)== LOW &&  digitalRead(BOUTON_2_PIN)== LOW ) {  
  delay(1000);
  timeS++;  
}
// new loop ! 

timeS=0;
count=0;
}
